{pkgs, ...}: {
  # TODO: re-enable this with the appropriate version?
  # programs.home-manager.enable = true;
  # programs.home-manager.path = https://github.com/rycee/home-manager/archive/445c0b1482c38172a9f8294ee16a7ca7462388e5.tar.gz;

  imports = [
    ../programs/zsh.nix
  ];

  nixpkgs.config = {
    allowBroken = false;
    allowUnfree = true;

    permittedInsecurePackages = [];
  };

  nix.settings.experimental-features = ["nix-command" "flakes" "impure-derivations" "ca-derivations" "recursive-nix"];
  nix.settings.sandbox = "relaxed";

  home.keyboard = {
    layout = "us";
    variant = "altgr-intl";
    options = [
      # nodeadkeys doesn't make sense with us layout: see https://man.archlinux.org/man/xkeyboard-config.7 for valid options
      # "nodeadkeys"
      # "caps:swapescape"
    ];
  };

  xdg.enable = true;

  programs.direnv.enable = true;
  services.lorri.enable = true;

  home.sessionVariables.NIXPKGS_ALLOW_UNFREE = "1";
  # Don't create .pyc files.
  home.sessionVariables.PYTHONDONTWRITEBYTECODE = "1";

  programs.command-not-found.enable = true;
  programs.fzf.enable = true;

  home.packages =
    []
    ++ (with pkgs; [
      htop
      vcsh

      # Authentication
      cacert
      openssl
      mkpasswd

      just
      ripgrep
      du-dust

      elfutils
      exfat
      file
      tree
      pwgen
      proot

      parted
      pv
      tmux
      wget
      curl

      # git helpers
      git-crypt
      gitFull
      pastebinit
      gist
      mr

      usbutils
      pciutils
    ]);

  home.stateVersion = "22.05";
}
