{
  pkgs,
  lib,
  config,
  ...
}: let
  passwords = import ../../../variables/passwords.crypt.nix;
in {
  networking.firewall.enable = true;
  networking.firewall.allowedTCPPorts = [
    # iperf3
    5201
  ];

  networking.firewall.logRefusedConnections = false;
  networking.usePredictableInterfaceNames = false;

  services.fprintd.enable = true;
  security.pam.services = {
    login.fprintAuth = true;
    sudo.fprintAuth = true;
  };

  time.timeZone = lib.mkForce passwords.timeZone.justyna;

  services = {
    xserver = {
      layout = lib.mkForce "de";
      xkbVariant = lib.mkForce "";
      xkbOptions = lib.mkForce "";
      displayManager.autoLogin.enable = true;
      displayManager.autoLogin.user = lib.mkForce "justyna";
      displayManager.gdm.enable = lib.mkForce true;
      displayManager.lightdm.enable = lib.mkForce false;
      desktopManager.gnome.enable = true;
    };

    # dbus.packages = [ pkgs.gnome3.dconf ];
    # udev.packages = [ pkgs.gnome3.gnome-settings-daemon ];
  };

  security.pki.certificateFiles = ["${pkgs.cacert}/etc/ssl/certs/ca-bundle.crt"];

  services.xserver.videoDrivers = ["modesetting"];

  boot.kernelPackages = lib.mkForce pkgs.linuxPackages_latest;

  nix.gc = {automatic = true;};
}
