{
  pkgs,
  lib,
  config,
  ...
}: let
  keys = import ../../../variables/keys.nix;
in {
  # TASK: new device
  networking.hostName = "steveej-pa600"; # Define your hostname.

  networking.firewall.enable = true;
  networking.firewall.allowedTCPPorts = [
    # iperf3
    5201
  ];

  networking.firewall.logRefusedConnections = false;
  networking.usePredictableInterfaceNames = false;

  services.printing = {
    enable = true;
    drivers = with pkgs; [hplip mfcl3770cdw.driver mfcl3770cdw.cupswrapper];
  };

  services.fprintd.enable = true;
  security.pam.services = {
    login.fprintAuth = true;
    sudo.fprintAuth = true;
  };

  security.pki.certificateFiles = ["${pkgs.cacert}/etc/ssl/certs/ca-bundle.crt"];

  services.xserver.videoDrivers = ["modesetting"];
  services.xserver.serverFlagsSection = ''
    Option "BlankTime" "0"
    Option "StandbyTime" "0"
    Option "SuspendTime" "0"
    Option "OffTime" "0"
  '';

  boot.kernelPackages = lib.mkForce pkgs.linuxPackages_latest;

  hardware.ledger.enable = true;
}
