{
  config,
  pkgs,
  lib,
  ...
}: {
  home-manager.users.steveej = import ../../../home-manager/configuration/text-minimal.nix {
    inherit pkgs;
  };

  nix.buildMachines = [
    {
      hostName = "localhost";
      system = "x86_64-linux";
      supportedFeatures = ["kvm" "nixos-test" "big-parallel" "benchmark"];
      maxJobs = 4;
    }
  ];

  services.hydra = {
    enable = false;
    hydraURL = "http://localhost:3000"; # externally visible URL
    notificationSender = "hydra@${config.networking.hostName}.stefanjunker.de"; # e-mail of hydra service
    # a standalone hydra will require you to unset the buildMachinesFiles list to avoid using a nonexistant /etc/nix/machines
    buildMachinesFiles = [];
    # you will probably also want, otherwise *everything* will be built from scratch
    useSubstitutes = true;
  };

  services.gitlab-runner = {
    enable = false;

    extraPackages = with pkgs; [bash gitlab-runner nix gitFull git-crypt];

    concurrent = 2;
    checkInterval = 0;
    services = {
      nixRunner = {
        executor = "shell";
        runUntagged = true;
        registrationConfigFile = "/etc/secrets/gitlab-runner/nix-runner.registration";
        tagList = ["nix"];
      };
    };
  };
}
