{
  pkgs,
  lib,
  ...
}: {
  networking.networkmanager = {
    enable = true;
    dns = "systemd-resolved";
    unmanaged = [
      "interface-name:veth*"
      "interface-name:virbr*"
      "interface-name:br*"
      "interface-name:*vbox*"
      "interface-name:*cni*"
    ];
  };
  networking.usePredictableInterfaceNames = false;

  services.resolved.enable = true;

  # hardware related services
  services.illum.enable = true;
  services.pcscd.enable = true;
  hardware.opengl.enable = true;
  hardware.bluetooth.enable = true;
  # required for running blueman-applet in user sessions
  services.dbus.packages = with pkgs; [blueman];
  services.blueman.enable = true;

  services.udev.packages = [pkgs.libu2f-host pkgs.yubikey-personalization pkgs.android-udev-rules];
  services.udev.extraRules = ''
    # OnePlusOne
    ATTR{idVendor}=="05c6", ATTR{idProduct}=="6764", SYMLINK+="libmtp-%k", MODE="660", GROUP="audio", ENV{ID_MTP_DEVICE}="1", ENV{ID_MEDIA_PLAYER}="1", TAG+="uaccess"
    ATTR{idVendor}=="05c6", ATTR{idProduct}=="6765", SYMLINK+="libmtp-%k", MODE="660", GROUP="audio", ENV{ID_MTP_DEVICE}="1", ENV{ID_MEDIA_PLAYER}="1", TAG+="uaccess"

    # Plantronics BackBeat PRO
    SUBSYSTEM=="usb", ATTR{idVendor}=="047f", ATTR{idProduct}=="011a", GROUP="users", MODE="0777"
    SUBSYSTEM=="usb", ATTR{idVendor}=="047f", ATTR{idProduct}=="fffe", GROUP="users", MODE="0777"
    SUBSYSTEM=="usb", ATTR{idVendor}=="047f", ATTR{idProduct}=="0001", GROUP="users", MODE="0777"

    # Yubikey 4/5 U2F+CCID
    SUBSYSTEM=="usb", ATTR{idVendor}=="1050", ATTR{idProduct}=="0406", ENV{ID_SECURITY_TOKEN}="1", GROUP="wheel"
  '';

  # services.samba.enable = true;
  # services.samba.extraConfig = ''
  #   client max protocol = SMB3
  #   # client min protocol = SMB2_10
  #   # client min protocol = NT1
  #   # ntlm auth = yes
  # '';

  services.logind.lidSwitchExternalPower = "ignore";

  services.printing = {
    enable = true;
    drivers = with pkgs; [mfcl3770cdwlpr mfcl3770cdwcupswrapper];
  };
}
